@@ -1,8 +1,9 @@
 print.anova.aodml <- function(x, ...) {
+  
   mod <- x$models
   dfr <- x$anova.table
   nam <- rownames(dfr)
-  cat("Analysis of Deviance Table\n\n")
+  cat("Likelihood ratio tests\n\n")
   sapply(mod, function(x) cat(x, "\n"))
   cat("\n")
   List <- lapply(dfr, function(x) ifelse(is.na(x), "", format(x, digits = 4)))
@@ -10,4 +11,5 @@ print.anova.aodml <- function(x, ...) {
   rownames(dfr) <- nam
   print(dfr)
   invisible(dfr)
-  }
+  
+}
